==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/af-ZA/auth/message.php <==
<?php

return array(

    'account_already_exists' => '\'N Rekening met hierdie e-pos bestaan ​​reeds.',
    'account_not_found'      => 'Die gebruikersnaam of wagwoord is verkeerd.',
    'account_not_activated'  => 'Hierdie gebruikers rekening is nie geaktiveer nie.',
    'account_suspended'      => 'Hierdie gebruikerrekening is opgeskort.',
    'account_banned'         => 'Hierdie gebruikerrekening is verban.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Jy is suksesvol aangemeld.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Kon nie jou inteken nie, probeer asseblief weer.',
        'success' => 'Jy is suksesvol aangemeld.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Kon nie jou rekening skep nie, probeer asseblief weer.',
        'success' => 'Rekening suksesvol geskep.',
    ),

    'forgot-password' => array(
        'error'   => 'Daar was \'n probleem tydens die herstel van wagwoordkode, probeer asseblief weer.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Kon nie jou wagwoord herstel nie, probeer asseblief weer.',
        'success' => 'Jou wagwoord is suksesvol gereset.',
    ),


);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/af-ZA/auth/message.php <==
<?php

return array(

    'account_already_exists' => '\'N Rekening met hierdie e-pos bestaan ​​reeds.',
    'account_not_found'      => 'Die gebruikersnaam of wagwoord is verkeerd.',
    'account_not_activated'  => 'Hierdie gebruikers rekening is nie geaktiveer nie.',
    'account_suspended'      => 'Hierdie gebruikerrekening is opgeskort.',
    'account_banned'         => 'Hierdie gebruikerrekening is verban.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Jy is suksesvol aangemeld.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Kon nie jou inteken nie, probeer asseblief weer.',
        'success' => 'Jy is suksesvol aangemeld.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Kon nie jou rekening skep nie, probeer asseblief weer.',
        'success' => 'Rekening suksesvol geskep.',
    ),

    'forgot-password' => array(
        'error'   => 'Daar was \'n probleem tydens die herstel van wagwoordkode, probeer asseblief weer.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Kon nie jou wagwoord herstel nie, probeer asseblief weer.',
        'success' => 'Jou wagwoord is suksesvol gereset.',
    ),


);
